@@ -280,6 +280,7 @@ static life3dstruct *life3ds = (life3dstruct *) NULL;
 
 static char *filePattern = (char *) NULL;
 
+#if 0
 static int
 invplot(int local_neighbors)
 {
@@ -306,14 +307,13 @@ invplot(int local_neighbors)
 			return 7;
 	}
 }
+#endif
 
 static int
 codeToPatternedRule(int local_neighbors, paramstruct param)
 {
 	unsigned int i;
-	int neighborKind;
 
-	neighborKind = invplot(local_neighbors);
 	switch (local_neighbors) {
 	case 12:
 		for (i = 0; i < LIFE_12RULES; i++)
@@ -353,9 +353,6 @@ static void
 copyFromPatternedRule(int local_neighbors, paramstruct * param,
 		int patterned_rule)
 {
-	int neighborKind;
-
-	neighborKind = invplot(local_neighbors);
 	switch (local_neighbors) {
 	case 12:
 		param->birth = param_12rules[patterned_rule].birth;
@@ -2647,15 +2644,20 @@ populateGliders(life3dstruct * lp, int dim, int orth,
 		int hsp, int vsp, int asp, int hoff, int voff, int aoff)
 {
 	if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12B3S3) {
+			(void) populateGlider(lp, glider_12B3S3[2], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
 		if (NRAND(3)) {
 			(void) populateGlider(lp, glider_12B3S3[0], dim,
 				hsp, vsp, asp, hoff, voff, aoff);
 		} else if (NRAND(3)) {
 			(void) populateGlider(lp, glider_12B3S3[1], dim,
 				hsp, vsp, asp, hoff, voff, aoff);
-		} else { /* lower probability of big glider */
+		} else if (NRAND(2)) { /* lower probability of big gliders */
 			(void) populateGlider(lp, glider_12B3S3[2], dim,
 				hsp, vsp, asp, hoff, voff, aoff);
+		} else {
+			(void) populateGlider(lp, glider_12B3S3[3], dim,
+				hsp, vsp, asp, hoff, voff, aoff);
 		}
 	} else if (lp->neighbors == 12 && lp->patterned_rule == LIFE_12B3S456) {
 		(void) populateGlider(lp, glider_12B3S456[0], dim,
