@@ -1899,7 +1899,7 @@ static void
 init_adam(ModeInfo * mi)
 {
 	loopstruct *lp = &loops[MI_SCREEN(mi)];
-	XPoint      start, dirx, diry;
+	XPoint      start;
 	int         i, j, dir;
 
 #ifdef DELAYDEBUGLOOP
@@ -1912,7 +1912,8 @@ init_adam(ModeInfo * mi)
 	if (!MI_COUNT(mi)) /* Probably doing testing so do not confuse */
 #endif
 	dir = NRAND(local_neighbors);
-
+	start.x = 0;
+	start.y = 0;
 	if (local_neighbors == 6) {
 		int k;
 
@@ -2057,6 +2058,9 @@ init_adam(ModeInfo * mi)
 		 hexReproducingLoop[j][i]);
 #endif
 	} else {
+		XPoint dirx, diry;
+		dirx.x = 0, dirx.y = 0;
+		diry.x = 0, diry.y = 0;
 		switch (dir) {
 			case 0:
 				start.x = (lp->bncols - sqAdamLoopX()) / 2;
