@@ -214,7 +214,7 @@ typedef struct para {
 }PARA;
 
 /*
-for the moment there are 11 distinc internal explosion types.
+for the moment there are 11 distinct internal explosion types.
 Each type has its own ID. An ID is a character between
 '0' and '9' or 'a' and 'z'. 'a' corresponds to 10 and
 'z' to 35. The type ID 42 is reserved for glyph explosions.
@@ -984,13 +984,14 @@ void init_pyro2(ModeInfo * mi)
 			return;
 
         if (messagefont == None && !(messagefont = XLoadQueryFont(display, modparam_fnt)))	{
-		fprintf(stderr, "can not find font '%s'\n", modparam_fnt);
-		release_pyro2(mi);
-		return;
+		fprintf(stderr, "can not find font '%s', using %s\n", modparam_fnt, DEFAULT_FNT);
+        	if (!(messagefont = XLoadQueryFont(display, DEFAULT_FNT))) {
+			release_pyro2(mi);
+			return;
+		}
 	}
 
 	pp = &pyros[MI_SCREEN(mi)];
-
 	if(!pp->gc) {
 		if(MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
 			XColor      color;
@@ -1332,31 +1333,32 @@ void release_pyro2(ModeInfo * mi)
 			for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 				pyrostruct *pp = &pyros[screen];
 
-				MI_WHITE_PIXEL(mi) = pp->whitepixel;
-				MI_BLACK_PIXEL(mi) = pp->blackpixel;
-#ifndef STANDALONE
-				MI_FG_PIXEL(mi) = pp->fg;
-				MI_BG_PIXEL(mi) = pp->bg;
-#endif
-
-				if(pp->colors && pp->ncolors) /* FIXME: if !no_colors */
+				if(pp->colors && pp->ncolors) { /* FIXME: if !no_colors */
 					free_colors(display, pp->cmap, pp->colors, pp->ncolors);
-
-				if(pp->colors != NULL)	free(pp->colors);
-
-				if(pp->cmap)	XFreeColormap(display, pp->cmap);
-
-				if(pp->gc != None)	XFreeGC(display, pp->gc);
+				}
+				if (pp->colors != NULL) {
+					free(pp->colors);
+				}
+				if (pp->cmap) {
+					XFreeColormap(display, pp->cmap);
+				}
+				if (pp->gc != None) {
+					MI_WHITE_PIXEL(mi) = pp->whitepixel;
+					MI_BLACK_PIXEL(mi) = pp->blackpixel;
+#ifndef STANDALONE
+					MI_FG_PIXEL(mi) = pp->fg;
+					MI_BG_PIXEL(mi) = pp->bg;
+#endif
+					XFreeGC(display, pp->gc);
+				}
 			}
 		}
-
 		free(pyros);
 		pyros = (pyrostruct *) NULL;
 	}
 	if (ostext != NULL)
 		free(ostext);
 	ostext = NULL;
-
 	return;
 }
 
@@ -1368,7 +1370,6 @@ void refresh_pyro2(ModeInfo * mi)
 	else {
 		MI_CLEARWINDOW(mi);
 	}
-
 	return;
 }
 
