@@ -849,16 +849,16 @@ LockStruct  LockProcs[] =
 	 refresh_bomb, change_bomb, (ModeHook *) NULL, &bomb_opts,
 	 100000, 10, 20, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows a bomb and will autologout after a time", 0, NULL},
-	{(char *) "random", init_random, draw_random, release_random,
-	 refresh_random, change_random, (ModeHook *) NULL, &random_opts,
-	 1, 1, 1, 1, 64, 1.0, (char *) "",
-	 (char *) "Shows a random mode (except blank and bomb)", 0, NULL},
-#else
-	{(char *) "random", init_random, draw_random, release_random,
-	 refresh_random, change_random, (ModeHook *) NULL, &random_opts,
-	 1, 1, 1, 1, 64, 1.0, (char *) "",
-	 (char *) "Shows a random mode (except blank)", 0, NULL},
 #endif
+	{(char *) "random", init_random, draw_random, release_random,
+	 refresh_random, change_random, (ModeHook *) NULL, &random_opts,
+	 1, 1, 1, 1, 64, 1.0, (char *) "",
+#ifdef MODE_bomb
+	 (char *) "Shows a random mode (except blank and bomb)",
+#else
+	 (char *) "Shows a random mode (except blank)",
+#endif
+	0, NULL},
 };
 
 int         numprocs = sizeof (LockProcs) / sizeof (LockProcs[0]);
