@@ -388,6 +388,7 @@ static const struct pam_conv PAM_conversation =
 #if !defined( ultrix ) && !defined( USE_PAM )
 static char userpass[PASSLENGTH];
 static char rootpass[PASSLENGTH];
+static char *crptpass = (char *) NULL;
 #ifdef USE_XLOCK_GROUP
 #include <grp.h>
 static char *grouppass = (char *) NULL;
@@ -1148,7 +1149,8 @@ checkPasswd(char *buffer)
 	if (usernet)
 		done = check_dce_net_passwd(user, buffer);
 	else
-		done = !strcmp(userpass, crypt(buffer, userpass));
+		done = ((crptpass = crypt(buffer, userpass)) &&
+			!strcmp(userpass, crptpass));
 
 	if (done)
 		return True;
@@ -1158,7 +1160,8 @@ checkPasswd(char *buffer)
 	if (rootnet)
 		done = check_dce_net_passwd(ROOT, buffer);
 	else
-		done = !strcmp(rootpass, crypt(buffer, rootpass));
+		done = ((crptpass = crypt(buffer, rootpass)) &&
+			!strcmp(rootpass, crptpass));
 #else /* !DCE_PASSWD */
 
 #ifdef USE_PAM
@@ -1379,7 +1382,8 @@ checkPasswd(char *buffer)
 		 * to make this more secure.
 		 */
 		for (pwll = pwllh; pwll->next; pwll = pwll->next)
-			if (!strcmp((char *) crypt(buffer, pwll->pw_passwd), pwll->pw_passwd)) {
+			if ((crptpass = crypt(buffer, pwll->pw_passwd)) &&
+					!strcmp((char *) crptpass, pwll->pw_passwd)) {
 #if ( HAVE_SYSLOG_H && defined( USE_SYSLOG ))
 				if (strcmp(user, pwll->pw_name) != 0)
 					syslog(SYSLOG_NOTICE, "%s: %s unlocked screen",
@@ -1390,11 +1394,13 @@ checkPasswd(char *buffer)
 	}
 #endif
 	if (!done) {
+		done = (
 #ifdef OSF1_ENH_SEC
-		done = (!strcmp((char *) dispcrypt(buffer, userpass, user_oldcrypt), userpass));
+			(crptpass = dispcrypt(buffer, userpass, user_oldcrypt)) &&
 #else
-		done = (!strcmp((char *) crypt(buffer, userpass), userpass));
+			(crptpass = crypt(buffer, userpass)) &&
 #endif
+			!strcmp((char *) crptpass, userpass));
 		/* userpass is used */
 		if (!*userpass && *buffer)
 			/*
@@ -1408,13 +1414,13 @@ checkPasswd(char *buffer)
 	(void) printf("buffer=%s, encrypt=%s, userpass=%s,\n", buffer,
 		      (char *) crypt(buffer, userpass), userpass);
 #endif
-	if (!done && allowroot
+	if (!done && allowroot &&
 #ifdef OSF1_ENH_SEC
-		&& !strcmp((char *) dispcrypt(buffer, rootpass, root_oldcrypt), rootpass)
+			(crptpass = dispcrypt(buffer, rootpass, root_oldcrypt)) &&
 #else
-		&& !strcmp((char *) crypt(buffer, rootpass), rootpass)
+			(crptpass = crypt(buffer, rootpass)) &&
 #endif
-	) {
+			!strcmp((char *) crptpass, rootpass)) {
 		done = True;
 		if (!(rootpass != NULL && *buffer))
 			/*
@@ -1707,9 +1713,9 @@ check_dce_net_passwd(char *usr, char *pass)
 				(void) fprintf(stderr, "sec_login_validate_identity failed: %s\n",
 					       error_string(error_status));
 			}
+			/* done with the copy of the password */
+			free(passcpy);
 		}
-		/* done with the copy of the password */
-		free(passcpy);
 	}
 	/* make sure that the authentication service is not an imposter */
 	if (valid) {
@@ -2267,11 +2273,13 @@ int checkGroupXlockPasswds(char *buffer)
 		return False;
 	}
 	while (grp->gr_mem[i]) {
+		unlock = (
 #ifdef OSF1_ENH_SEC
-		unlock = (!strcmp((char *) dispcrypt(buffer, &grouppass[i * PASSLENGTH1], user_oldcrypt), &grouppass[i * PASSLENGTH1]));
+			(crptpass = dispcrypt(buffer, &grouppass[i * PASSLENGTH1], user_oldcrypt)) &&
 #else
-		unlock = (!strcmp((char *) crypt(buffer, &grouppass[i * PASSLENGTH1]), &grouppass[i * PASSLENGTH1]));
+			(crptpass = crypt(buffer, &grouppass[i * PASSLENGTH1])) &&
 #endif
+			!strcmp((char *) crptpass, &grouppass[i * PASSLENGTH1]));
 #if 0
 		/* For debugging only! */
 		(void) printf("gbuffer=%s, encrypt=%s, grouppass=%s,\n", buffer,
