@@ -173,7 +173,7 @@ static int  descr();
 #define DEF_BG		"White"
 #define DEF_FG		"Black"
 
-/* language depended resources */
+/* language dependant resources */
 #if defined FR
 #include "resource-msg-fr.h"
 #elif defined NL
@@ -443,8 +443,8 @@ static XrmOptionDescRec genTable[] =
 #endif
 #ifdef USE_BUTTON_LOGOUT
 	{(char *) "-logoutButton", (char *) ".logoutButton", XrmoptionSepArg, (caddr_t) NULL},
-{(char *) "-logoutButtonLabel", (char *) ".logoutButtonLabel", XrmoptionSepArg, (caddr_t) NULL},
- {(char *) "-logoutButtonHelp", (char *) ".logoutButtonHelp", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-logoutButtonLabel", (char *) ".logoutButtonLabel", XrmoptionSepArg, (caddr_t) NULL},
+	{(char *) "-logoutButtonHelp", (char *) ".logoutButtonHelp", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-logoutFailedString", (char *) ".logoutFailedString", XrmoptionSepArg, (caddr_t) NULL},
 #endif
 #ifdef USE_DTSAVER
@@ -668,8 +668,8 @@ static OptionStruct opDesc[] =
 #endif
 #ifdef USE_BUTTON_LOGOUT
 	{(char *) "-logoutButton minutes", (char *) "number of minutes until logout button appears (not more than forced button time)"},
-    {(char *) "-logoutButtonLabel string", (char *) "text string to use inside logout button"},
-   {(char *) "-logoutButtonHelp string", (char *) "text string to use for logout button help"},
+	{(char *) "-logoutButtonLabel string", (char *) "text string to use inside logout button"},
+	{(char *) "-logoutButtonHelp string", (char *) "text string to use for logout button help"},
 	{(char *) "-logoutFailedString string", (char *) "text string to use for failed logout attempts"},
 #endif
 #ifdef USE_DTSAVER
@@ -964,7 +964,7 @@ static argtype genvars[] =
 	{(void *) & cpasswd, (char *) "cpasswd", (char *) "cpasswd", (char *) "", t_String},
 #endif
 #ifdef USE_AUTO_LOGOUT
-	{(void *) & logoutAuto, (char *) "logoutAuto", (char *) "logoutAuto", (char *) DEF_AUTO_LOGOUT, t_Int},
+	{(void *) & logoutAuto, (char *) "logoutAuto", (char *) "LogoutAuto", (char *) DEF_AUTO_LOGOUT, t_Int},
 #endif
 #ifdef USE_BUTTON_LOGOUT
 	{(void *) & logoutButton, (char *) "logoutButton", (char *) "LogoutButton", (char *) DEF_BUTTON_LOGOUT, t_Int},
